==> nextcloud-app-contacts-3.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ar.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "جهات الاتصال",
    "All contacts" : "كل الجهات",
    "Details" : "التفاصيل",
    "Download" : "تحميل",
    "Delete" : "حذف",
    "Groups" : "مجموعات",
    "New contact" : "جهة إتصال جديدة",
    "Copy link" : "نسخ الرابط",
    "Rename" : "تعديل الإسم",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "Import into" : "إستيراد إلى",
    "First name" : "الإسم",
    "Last name" : "اللقب",
    "Nickname" : "كنية.\nلقب.",
    "Detailed name" : "الإسم بالتفصيل",
    "Additional names" : "الأسماء الإضافية",
    "Prefix" : "بادئة",
    "Suffix" : "لاحقة",
    "Notes" : "الملاحظات",
    "Website" : "موقع إلكتروني",
    "Federated Cloud ID" : "معرّف السحابة الخارجية",
    "Home" : "المنزل",
    "Work" : "العمل",
    "Other" : "آخر",
    "Address" : "العنوان",
    "Post office box" : "صندوق البريد",
    "City" : "المدينة",
    "State or province" : "الولاية أو المنطقة.",
    "Postal code" : "الرمز البريدي.",
    "Country" : "البلد",
    "Birthday" : "عيد ميلاد",
    "Anniversary" : "ذكرى سنوية",
    "Date of death" : "تاريخ الوفاة",
    "Email" : "البريد الإلكترونى",
    "Instant messaging" : "المراسلة الفورية",
    "Phone" : "الهاتف",
    "Mobile" : "الهاتف المحمول",
    "Fax" : "الفاكس",
    "Fax home" : "فاكس المنزل",
    "Fax work" : "فاكس العمل",
    "Pager" : "النداء",
    "Voice" : "صوت",
    "Social network" : "شبكة اجتماعية"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-app-contacts-3.2.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/ar.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "جهات الاتصال",
    "All contacts" : "كل الجهات",
    "Details" : "التفاصيل",
    "Add a new picture" : "إضافة صورة جديدة",
    "Download picture" : "تنزيل الصورة",
    "Delete picture" : "حذف الصورة",
    "Upload a new picture" : "تحميل صورة جديدة",
    "Loading" : "Loading",
    "Name" : "الاسم",
    "Company" : "الشركة",
    "Title" : "العنوان",
    "Download" : "تحميل",
    "Delete" : "حذف",
    "Addressbook" : "دفتر العناوين",
    "Groups" : "مجموعات",
    "New contact" : "جهة إتصال جديدة",
    "No errors" : "لا توجد أخطاء",
    "No results" : "دون أية نتيجة",
    "Last modified" : "آخر تعديل",
    "Rename" : "تعديل الإسم",
    "Enabled" : "مفعلة",
    "Disabled" : "معطّل",
    "Copy link" : "نسخ الرابط",
    "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
    "can edit" : "يمكن التعديل",
    "Address book name" : "اسم دفتر العناوين",
    "First name" : "الإسم",
    "Last name" : "اللقب",
    "Display name" : "الاسم المعروض",
    "Not grouped" : "غير مصنف",
    "Nickname" : "كنية.\nلقب.",
    "Detailed name" : "الإسم بالتفصيل",
    "Additional names" : "الأسماء الإضافية",
    "Prefix" : "بادئة",
    "Suffix" : "لاحقة",
    "Notes" : "الملاحظات",
    "Website" : "موقع إلكتروني",
    "Location" : "المكان",
    "Federated Cloud ID" : "معرّف السحابة الخارجية",
    "Home" : "المنزل",
    "Work" : "العمل",
    "Other" : "آخر",
    "Address" : "العنوان",
    "Post office box" : "صندوق البريد",
    "City" : "المدينة",
    "State or province" : "الولاية أو المنطقة.",
    "Postal code" : "الرمز البريدي.",
    "Country" : "البلد",
    "Birthday" : "عيد ميلاد",
    "Anniversary" : "ذكرى سنوية",
    "Date of death" : "تاريخ الوفاة",
    "Email" : "البريد الإلكترونى",
    "Instant messaging" : "المراسلة الفورية",
    "Phone" : "الهاتف",
    "Mobile" : "الهاتف المحمول",
    "Fax" : "الفاكس",
    "Fax home" : "فاكس المنزل",
    "Fax work" : "فاكس العمل",
    "Pager" : "النداء",
    "Voice" : "صوت",
    "Social network" : "شبكة اجتماعية",
    "Relative" : "مرتبط",
    "None" : "لا شيء",
    "Unknown" : "مجهول",
    "Timezone" : "المنطقة الزمنية",
    "An error occurred" : "طرأ هناك خطأ"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
